diff --git a/modules/custom/improved_theme_settings/improved_theme_settings.module b/modules/custom/improved_theme_settings/improved_theme_settings.module
index 04c9a16..13fd74f 100644
--- a/modules/custom/improved_theme_settings/improved_theme_settings.module
+++ b/modules/custom/improved_theme_settings/improved_theme_settings.module
@@ -267,8 +267,8 @@ function improved_theme_settings_page_attachments(array &$page) {
   // If socialblue is our default theme.
   $system_theme_settings = \Drupal::configFactory()->get('system.theme')->get('default');
 
-  // We render our color & font settings in the head. Only if socialblue is
-  // the default theme. And only if the current active theme is socialblue.
+  // We render our color & font settings in the head. Only if the default theme
+  // is a subtheme of socialbase. And only if this subtheme is active.
   // Otherwise we also render it on all admin pages.
   if (array_key_exists('socialbase', \Drupal::service('theme.manager')->getActiveTheme()->getBaseThemes())) {
     if ($active_theme == $system_theme_settings) {
diff --git a/modules/social_features/social_activity/social_activity.install b/modules/social_features/social_activity/social_activity.install
index 4081b64..e50b581 100644
--- a/modules/social_features/social_activity/social_activity.install
+++ b/modules/social_features/social_activity/social_activity.install
@@ -78,8 +78,6 @@ function _social_activity_create_activity_homepage_block() {
     $config_update_service->import('view', 'activity_stream');
   }
 
-  $config = \Drupal::configFactory();
-
   // Do not add a new block if it already exists.
   $block = Block::load('views_block__activity_stream_block_stream_homepage');
   if (!isset($block)) {
@@ -96,7 +94,7 @@ function _social_activity_create_activity_homepage_block() {
       'plugin' => 'views_block:activity_stream-block_stream_homepage',
       'region' => 'content',
       'id' => 'views_block__activity_stream_block_stream_homepage',
-      'theme' => $config->get('system.theme')->get('default'),
+      'theme' => array_key_exists('socialbase', \Drupal::service('theme.manager')->getActiveTheme()->getBaseThemes()),
       'label' => '',
       'visibility' => $visibility,
       'weight' => NULL,
diff --git a/themes/socialblue/theme-settings.php b/themes/socialblue/theme-settings.php
index 6df7b44..5ad5e52 100644
--- a/themes/socialblue/theme-settings.php
+++ b/themes/socialblue/theme-settings.php
@@ -19,9 +19,9 @@ function socialblue_form_system_theme_settings_alter(&$form, FormStateInterface
 
   $system_theme_settings = \Drupal::configFactory()->get('system.theme')->get('default');
 
   // If the default theme is either socialblue or socialsaas then extend
   // the form in the appearance section.
-  if ($system_theme_settings == 'socialblue' || $system_theme_settings == 'socialsaas') {
+  if (array_key_exists('socialbase', \Drupal::service('theme.manager')->getActiveTheme()->getBaseThemes())) {
     $config = \Drupal::config($system_theme_settings . '.settings');
 
     $form['open_social_settings'] = [
@@ -19,9 +19,9 @@ function socialblue_form_system_theme_settings_alter(&$form, FormStateInterface
   $system_theme_settings = \Drupal::configFactory()->get('system.theme')->get('default');
 
-  // If the default theme is either socialblue or socialsaas then extend
+  // If the default theme is a subtheme of socialbase then extend
   // the form in the appearance section.
